fireworks.user_objects.queue_adapters.tests package — FireWorks 2.0.4 documentation

# fireworks.user_objects.queue_adapters.tests package

## Submodules

## fireworks.user_objects.queue_adapters.tests.test_common_adapter module

TODO: Modify unittest doc.

class fireworks.user_objects.queue_adapters.tests.test_common_adapter.CommonAdapterTest(methodName='runTest')

  Bases: `TestCase`

  test_override() → None
  test_parse_jobid() → None
  test_parse_njobs() → None
  test_serialization() → None
  test_status_cmd_pbs() → None
  test_yaml_load() → None

## Module contents

Tests for queue adapters.